@@ -1,6 +1,5 @@
 use v6;
 
-use PDF::COS::Dict;
 use PDF::COS::Stream;
 use PDF::Class::Type;
 
@@ -19,6 +18,6 @@ class PDF::CMap
     has Hash $.CIDSystemInfo is entry(:required);         #| (Required) A dictionary containing entries that define the character collection for the CIDFont or CIDFonts associated with the CMap
     my subset ZeroOrOne of UInt where 0|1;
     has ZeroOrOne $.WMode is entry;                       #| (Optional) A code that determines the writing mode for any CIDFont with which this CMap is combined. The possible values are 0 for horizontal and 1 for vertical
-    my subset NameOrStream where PDF::COS::Name | PDF::COS::Stream;
-    has NameOrStream $.UseCMap is entry;                  #| (Optional) The name of a predefined CMap, or a stream containing a CMap, that is to be used as the base for this CMap
+    my subset NameOrCMap where PDF::COS::Name | PDF::COS::Stream;
+    has NameOrCMap $.UseCMap is entry;                  #| (Optional) The name of a predefined CMap, or a stream containing a CMap, that is to be used as the base for this CMap
 }
